@@ -16,6 +16,7 @@ from .impl import DefaultImpl
 from .. import util
 from ..autogenerate import compare
 from ..util.compat import string_types
+from ..util.sqla_compat import _is_mariadb
 from ..util.sqla_compat import _is_type_bound
 from ..util.sqla_compat import sqla_100
 
@@ -43,13 +44,15 @@ class MySQLImpl(DefaultImpl):
         existing_comment=None,
         **kw
     ):
-        if name is not None:
+        if name is not None or self._is_mysql_allowed_functional_default(
+            type_ if type_ is not None else existing_type, server_default
+        ):
             self._exec(
                 MySQLChangeColumn(
                     table_name,
                     column_name,
                     schema=schema,
-                    newname=name,
+                    newname=name if name is not None else column_name,
                     nullable=nullable
                     if nullable is not None
                     else existing_nullable
@@ -106,6 +109,13 @@ class MySQLImpl(DefaultImpl):
 
         super(MySQLImpl, self).drop_constraint(const)
 
+    def _is_mysql_allowed_functional_default(self, type_, server_default):
+        return (
+            type_ is not None
+            and type_._type_affinity is sqltypes.DateTime
+            and server_default is not None
+        )
+
     def compare_server_default(
         self,
         inspector_column,
@@ -126,12 +136,36 @@ class MySQLImpl(DefaultImpl):
         ):
             return False
         elif inspector_column.type._type_affinity is sqltypes.Integer:
-            rendered_inspector_default = re.sub(
-                r"^'|'$", "", rendered_inspector_default
-            ) if rendered_inspector_default is not None else None
+            rendered_inspector_default = (
+                re.sub(r"^'|'$", "", rendered_inspector_default)
+                if rendered_inspector_default is not None
+                else None
+            )
             return rendered_inspector_default != rendered_metadata_default
         elif rendered_inspector_default and rendered_metadata_default:
-            # adjust for "function()" vs. "FUNCTION"
+            # adjust for "function()" vs. "FUNCTION" as can occur particularly
+            # for the CURRENT_TIMESTAMP function on newer MariaDB versions
+
+            # SQLAlchemy MySQL dialect bundles ON UPDATE into the server
+            # default; adjust for this possibly being present.
+            onupdate_ins = re.match(
+                r"(.*) (on update.*?)(?:\(\))?$",
+                rendered_inspector_default.lower(),
+            )
+            onupdate_met = re.match(
+                r"(.*) (on update.*?)(?:\(\))?$",
+                rendered_metadata_default.lower(),
+            )
+
+            if onupdate_ins:
+                if not onupdate_met:
+                    return True
+                elif onupdate_ins.group(2) != onupdate_met.group(2):
+                    return True
+
+                rendered_inspector_default = onupdate_ins.group(1)
+                rendered_metadata_default = onupdate_met.group(1)
+
             return re.sub(
                 r"(.*?)(?:\(\))?$", r"\1", rendered_inspector_default.lower()
             ) != re.sub(
@@ -403,10 +437,16 @@ def _mysql_drop_constraint(element, compiler, **kw):
         # note that SQLAlchemy as of 1.2 does not yet support
         # DROP CONSTRAINT for MySQL/MariaDB, so we implement fully
         # here.
-        return "ALTER TABLE %s DROP CONSTRAINT %s" % (
-            compiler.preparer.format_table(constraint.table),
-            compiler.preparer.format_constraint(constraint),
-        )
+        if _is_mariadb(compiler.dialect):
+            return "ALTER TABLE %s DROP CONSTRAINT %s" % (
+                compiler.preparer.format_table(constraint.table),
+                compiler.preparer.format_constraint(constraint),
+            )
+        else:
+            return "ALTER TABLE %s DROP CHECK %s" % (
+                compiler.preparer.format_table(constraint.table),
+                compiler.preparer.format_constraint(constraint),
+            )
     else:
         raise NotImplementedError(
             "No generic 'DROP CONSTRAINT' in MySQL - "
