@@ -1,14 +1,21 @@
+from contextlib import contextmanager
 import logging
 import sys
-from contextlib import contextmanager
 
-from sqlalchemy import MetaData, Table, Column, String, literal_column,\
-    PrimaryKeyConstraint
-from sqlalchemy.engine.strategies import MockEngineStrategy
+from sqlalchemy import Column
+from sqlalchemy import literal_column
+from sqlalchemy import MetaData
+from sqlalchemy import PrimaryKeyConstraint
+from sqlalchemy import String
+from sqlalchemy import Table
+from sqlalchemy.engine import Connection
 from sqlalchemy.engine import url as sqla_url
+from sqlalchemy.engine.strategies import MockEngineStrategy
 
-from ..util.compat import callable, EncodedIO
-from .. import ddl, util
+from .. import ddl
+from .. import util
+from ..util.compat import callable
+from ..util.compat import EncodedIO
 
 log = logging.getLogger(__name__)
 
@@ -64,70 +71,82 @@ class MigrationContext(object):
         self.environment_context = environment_context
         self.opts = opts
         self.dialect = dialect
-        self.script = opts.get('script')
-        as_sql = opts.get('as_sql', False)
+        self.script = opts.get("script")
+        as_sql = opts.get("as_sql", False)
         transactional_ddl = opts.get("transactional_ddl")
         self._transaction_per_migration = opts.get(
-            "transaction_per_migration", False)
+            "transaction_per_migration", False
+        )
+        self.on_version_apply_callbacks = opts.get("on_version_apply", ())
 
         if as_sql:
             self.connection = self._stdout_connection(connection)
             assert self.connection is not None
         else:
             self.connection = connection
-        self._migrations_fn = opts.get('fn')
+        self._migrations_fn = opts.get("fn")
         self.as_sql = as_sql
 
         if "output_encoding" in opts:
             self.output_buffer = EncodedIO(
                 opts.get("output_buffer") or sys.stdout,
-                opts['output_encoding']
+                opts["output_encoding"],
             )
         else:
             self.output_buffer = opts.get("output_buffer", sys.stdout)
 
-        self._user_compare_type = opts.get('compare_type', False)
+        self._user_compare_type = opts.get("compare_type", False)
         self._user_compare_server_default = opts.get(
-            'compare_server_default',
-            False)
+            "compare_server_default", False
+        )
         self.version_table = version_table = opts.get(
-            'version_table', 'alembic_version')
-        self.version_table_schema = version_table_schema = \
-            opts.get('version_table_schema', None)
+            "version_table", "alembic_version"
+        )
+        self.version_table_schema = version_table_schema = opts.get(
+            "version_table_schema", None
+        )
         self._version = Table(
-            version_table, MetaData(),
-            Column('version_num', String(32), nullable=False),
-            schema=version_table_schema)
+            version_table,
+            MetaData(),
+            Column("version_num", String(32), nullable=False),
+            schema=version_table_schema,
+        )
         if opts.get("version_table_pk", True):
             self._version.append_constraint(
                 PrimaryKeyConstraint(
-                    'version_num', name="%s_pkc" % version_table
+                    "version_num", name="%s_pkc" % version_table
                 )
             )
 
         self._start_from_rev = opts.get("starting_rev")
         self.impl = ddl.DefaultImpl.get_by_dialect(dialect)(
-            dialect, self.connection, self.as_sql,
+            dialect,
+            self.connection,
+            self.as_sql,
             transactional_ddl,
             self.output_buffer,
-            opts
+            opts,
         )
         log.info("Context impl %s.", self.impl.__class__.__name__)
         if self.as_sql:
             log.info("Generating static SQL")
-        log.info("Will assume %s DDL.",
-                 "transactional" if self.impl.transactional_ddl
-                 else "non-transactional")
+        log.info(
+            "Will assume %s DDL.",
+            "transactional"
+            if self.impl.transactional_ddl
+            else "non-transactional",
+        )
 
     @classmethod
-    def configure(cls,
-                  connection=None,
-                  url=None,
-                  dialect_name=None,
-                  dialect=None,
-                  environment_context=None,
-                  opts=None,
-                  ):
+    def configure(
+        cls,
+        connection=None,
+        url=None,
+        dialect_name=None,
+        dialect=None,
+        environment_context=None,
+        opts=None,
+    ):
         """Create a new :class:`.MigrationContext`.
 
         This is a factory method usually called
@@ -152,6 +171,13 @@ class MigrationContext(object):
             opts = {}
 
         if connection:
+            if not isinstance(connection, Connection):
+                util.warn(
+                    "'connection' argument to configure() is expected "
+                    "to be a sqlalchemy.engine.Connection instance, "
+                    "got %r" % connection,
+                    stacklevel=3
+                )
             dialect = connection.dialect
         elif url:
             url = sqla_url.make_url(url)
@@ -168,22 +194,28 @@ class MigrationContext(object):
         transaction_now = _per_migration == self._transaction_per_migration
 
         if not transaction_now:
+
             @contextmanager
             def do_nothing():
                 yield
+
             return do_nothing()
 
         elif not self.impl.transactional_ddl:
+
             @contextmanager
             def do_nothing():
                 yield
+
             return do_nothing()
         elif self.as_sql:
+
             @contextmanager
             def begin_commit():
                 self.impl.emit_begin()
                 yield
                 self.impl.emit_commit()
+
             return begin_commit()
         else:
             return self.bind.begin()
@@ -210,7 +242,8 @@ class MigrationContext(object):
         elif len(heads) > 1:
             raise util.CommandError(
                 "Version table '%s' has more than one head present; "
-                "please use get_current_heads()" % self.version_table)
+                "please use get_current_heads()" % self.version_table
+            )
         else:
             return heads[0]
 
@@ -236,18 +269,20 @@ class MigrationContext(object):
         """
         if self.as_sql:
             start_from_rev = self._start_from_rev
-            if start_from_rev == 'base':
+            if start_from_rev == "base":
                 start_from_rev = None
             elif start_from_rev is not None and self.script:
-                start_from_rev = \
-                    self.script.get_revision(start_from_rev).revision
+                start_from_rev = self.script.get_revision(
+                    start_from_rev
+                ).revision
 
             return util.to_tuple(start_from_rev, default=())
         else:
             if self._start_from_rev:
                 raise util.CommandError(
                     "Can't specify current_rev to context "
-                    "when using a database connection")
+                    "when using a database connection"
+                )
             if not self._has_version_table():
                 return ()
         return tuple(
@@ -259,7 +294,8 @@ class MigrationContext(object):
 
     def _has_version_table(self):
         return self.connection.dialect.has_table(
-            self.connection, self.version_table, self.version_table_schema)
+            self.connection, self.version_table, self.version_table_schema
+        )
 
     def stamp(self, script_directory, revision):
         """Stamp the version table with a specific revision.
@@ -280,7 +316,7 @@ class MigrationContext(object):
             head_maintainer.update_to_step(step)
 
     def run_migrations(self, **kw):
-        """Run the migration scripts established for this
+        r"""Run the migration scripts established for this
         :class:`.MigrationContext`, if any.
 
         The commands in :mod:`alembic.command` will set up a function
@@ -308,6 +344,10 @@ class MigrationContext(object):
 
         head_maintainer = HeadMaintainer(self, heads)
 
+        starting_in_transaction = (
+            not self.as_sql and self._in_connection_transaction()
+        )
+
         for step in self._migrations_fn(heads, self):
             with self.begin_transaction(_per_migration=True):
                 if self.as_sql and not head_maintainer.heads:
@@ -316,7 +356,9 @@ class MigrationContext(object):
                     self._version.create(self.connection)
                 log.info("Running %s", step)
                 if self.as_sql:
-                    self.impl.static_output("-- Running %s" % (step.short_log,))
+                    self.impl.static_output(
+                        "-- Running %s" % (step.short_log,)
+                    )
                 step.migration_fn(**kw)
 
                 # previously, we wouldn't stamp per migration
@@ -325,18 +367,37 @@ class MigrationContext(object):
                 # and row-targeted updates and deletes, it's simpler for now
                 # just to run the operations on every version
                 head_maintainer.update_to_step(step)
+                for callback in self.on_version_apply_callbacks:
+                    callback(
+                        ctx=self,
+                        step=step.info,
+                        heads=set(head_maintainer.heads),
+                        run_args=kw,
+                    )
 
-            if not self.as_sql and not self.impl.transactional_ddl and \
-                    self.connection.in_transaction():
+            if (
+                not starting_in_transaction
+                and not self.as_sql
+                and not self.impl.transactional_ddl
+                and self._in_connection_transaction()
+            ):
                 raise util.CommandError(
-                    "Migration \"%s\" has left an uncommitted "
+                    'Migration "%s" has left an uncommitted '
                     "transaction opened; transactional_ddl is False so "
-                    "Alembic is not committing transactions"
-                    % step)
+                    "Alembic is not committing transactions" % step
+                )
 
         if self.as_sql and not head_maintainer.heads:
             self._version.drop(self.connection)
 
+    def _in_connection_transaction(self):
+        try:
+            meth = self.connection.in_transaction
+        except AttributeError:
+            return False
+        else:
+            return meth()
+
     def execute(self, sql, execution_options=None):
         """Execute a SQL construct or string statement.
 
@@ -397,19 +458,20 @@ class MigrationContext(object):
                 inspector_column,
                 metadata_column,
                 inspector_column.type,
-                metadata_column.type
+                metadata_column.type,
             )
             if user_value is not None:
                 return user_value
 
-        return self.impl.compare_type(
-            inspector_column,
-            metadata_column)
+        return self.impl.compare_type(inspector_column, metadata_column)
 
-    def _compare_server_default(self, inspector_column,
-                                metadata_column,
-                                rendered_metadata_default,
-                                rendered_column_default):
+    def _compare_server_default(
+        self,
+        inspector_column,
+        metadata_column,
+        rendered_metadata_default,
+        rendered_column_default,
+    ):
 
         if self._user_compare_server_default is False:
             return False
@@ -421,7 +483,7 @@ class MigrationContext(object):
                 metadata_column,
                 rendered_column_default,
                 metadata_column.server_default,
-                rendered_metadata_default
+                rendered_metadata_default,
             )
             if user_value is not None:
                 return user_value
@@ -430,7 +492,8 @@ class MigrationContext(object):
             inspector_column,
             metadata_column,
             rendered_metadata_default,
-            rendered_column_default)
+            rendered_column_default,
+        )
 
 
 class HeadMaintainer(object):
@@ -443,8 +506,7 @@ class HeadMaintainer(object):
         self.heads.add(version)
 
         self.context.impl._exec(
-            self.context._version.insert().
-            values(
+            self.context._version.insert().values(
                 version_num=literal_column("'%s'" % version)
             )
         )
@@ -454,15 +516,17 @@ class HeadMaintainer(object):
 
         ret = self.context.impl._exec(
             self.context._version.delete().where(
-                self.context._version.c.version_num ==
-                literal_column("'%s'" % version)))
+                self.context._version.c.version_num
+                == literal_column("'%s'" % version)
+            )
+        )
         if not self.context.as_sql and ret.rowcount != 1:
             raise util.CommandError(
                 "Online migration expected to match one "
                 "row when deleting '%s' in '%s'; "
                 "%d found"
-                % (version,
-                   self.context.version_table, ret.rowcount))
+                % (version, self.context.version_table, ret.rowcount)
+            )
 
     def _update_version(self, from_, to_):
         assert to_ not in self.heads
@@ -470,17 +534,20 @@ class HeadMaintainer(object):
         self.heads.add(to_)
 
         ret = self.context.impl._exec(
-            self.context._version.update().
-            values(version_num=literal_column("'%s'" % to_)).where(
+            self.context._version.update()
+            .values(version_num=literal_column("'%s'" % to_))
+            .where(
                 self.context._version.c.version_num
-                == literal_column("'%s'" % from_))
+                == literal_column("'%s'" % from_)
+            )
         )
         if not self.context.as_sql and ret.rowcount != 1:
             raise util.CommandError(
                 "Online migration expected to match one "
                 "row when updating '%s' to '%s' in '%s'; "
                 "%d found"
-                % (from_, to_, self.context.version_table, ret.rowcount))
+                % (from_, to_, self.context.version_table, ret.rowcount)
+            )
 
     def update_to_step(self, step):
         if step.should_delete_branch(self.heads):
@@ -493,20 +560,32 @@ class HeadMaintainer(object):
             self._insert_version(vers)
         elif step.should_merge_branches(self.heads):
             # delete revs, update from rev, update to rev
-            (delete_revs, update_from_rev,
-             update_to_rev) = step.merge_branch_idents(self.heads)
+            (
+                delete_revs,
+                update_from_rev,
+                update_to_rev,
+            ) = step.merge_branch_idents(self.heads)
             log.debug(
                 "merge, delete %s, update %s to %s",
-                delete_revs, update_from_rev, update_to_rev)
+                delete_revs,
+                update_from_rev,
+                update_to_rev,
+            )
             for delrev in delete_revs:
                 self._delete_version(delrev)
             self._update_version(update_from_rev, update_to_rev)
         elif step.should_unmerge_branches(self.heads):
-            (update_from_rev, update_to_rev,
-             insert_revs) = step.unmerge_branch_idents(self.heads)
+            (
+                update_from_rev,
+                update_to_rev,
+                insert_revs,
+            ) = step.unmerge_branch_idents(self.heads)
             log.debug(
                 "unmerge, insert %s, update %s to %s",
-                insert_revs, update_from_rev, update_to_rev)
+                insert_revs,
+                update_from_rev,
+                update_to_rev,
+            )
             for insrev in insert_revs:
                 self._insert_version(insrev)
             self._update_version(update_from_rev, update_to_rev)
@@ -516,6 +595,139 @@ class HeadMaintainer(object):
             self._update_version(from_, to_)
 
 
+class MigrationInfo(object):
+    """Exposes information about a migration step to a callback listener.
+
+    The :class:`.MigrationInfo` object is available exclusively for the
+    benefit of the :paramref:`.EnvironmentContext.on_version_apply`
+    callback hook.
+
+    .. versionadded:: 0.9.3
+
+    """
+
+    is_upgrade = None
+    """True/False: indicates whether this operation ascends or descends the
+    version tree."""
+
+    is_stamp = None
+    """True/False: indicates whether this operation is a stamp (i.e. whether
+    it results in any actual database operations)."""
+
+    up_revision_id = None
+    """Version string corresponding to :attr:`.Revision.revision`.
+
+    In the case of a stamp operation, it is advised to use the
+    :attr:`.MigrationInfo.up_revision_ids` tuple as a stamp operation can
+    make a single movement from one or more branches down to a single
+    branchpoint, in which case there will be multiple "up" revisions.
+
+    .. seealso::
+
+        :attr:`.MigrationInfo.up_revision_ids`
+
+    """
+
+    up_revision_ids = None
+    """Tuple of version strings corresponding to :attr:`.Revision.revision`.
+
+    In the majority of cases, this tuple will be a single value, synonomous
+    with the scalar value of :attr:`.MigrationInfo.up_revision_id`.
+    It can be multiple revision identifiers only in the case of an
+    ``alembic stamp`` operation which is moving downwards from multiple
+    branches down to their common branch point.
+
+    .. versionadded:: 0.9.4
+
+    """
+
+    down_revision_ids = None
+    """Tuple of strings representing the base revisions of this migration step.
+
+    If empty, this represents a root revision; otherwise, the first item
+    corresponds to :attr:`.Revision.down_revision`, and the rest are inferred
+    from dependencies.
+    """
+
+    revision_map = None
+    """The revision map inside of which this operation occurs."""
+
+    def __init__(
+        self, revision_map, is_upgrade, is_stamp, up_revisions, down_revisions
+    ):
+        self.revision_map = revision_map
+        self.is_upgrade = is_upgrade
+        self.is_stamp = is_stamp
+        self.up_revision_ids = util.to_tuple(up_revisions, default=())
+        if self.up_revision_ids:
+            self.up_revision_id = self.up_revision_ids[0]
+        else:
+            # this should never be the case with
+            # "upgrade", "downgrade", or "stamp" as we are always
+            # measuring movement in terms of at least one upgrade version
+            self.up_revision_id = None
+        self.down_revision_ids = util.to_tuple(down_revisions, default=())
+
+    @property
+    def is_migration(self):
+        """True/False: indicates whether this operation is a migration.
+
+        At present this is true if and only the migration is not a stamp.
+        If other operation types are added in the future, both this attribute
+        and :attr:`~.MigrationInfo.is_stamp` will be false.
+        """
+        return not self.is_stamp
+
+    @property
+    def source_revision_ids(self):
+        """Active revisions before this migration step is applied."""
+        return (
+            self.down_revision_ids if self.is_upgrade else self.up_revision_ids
+        )
+
+    @property
+    def destination_revision_ids(self):
+        """Active revisions after this migration step is applied."""
+        return (
+            self.up_revision_ids if self.is_upgrade else self.down_revision_ids
+        )
+
+    @property
+    def up_revision(self):
+        """Get :attr:`~.MigrationInfo.up_revision_id` as
+        a :class:`.Revision`.
+
+        """
+        return self.revision_map.get_revision(self.up_revision_id)
+
+    @property
+    def up_revisions(self):
+        """Get :attr:`~.MigrationInfo.up_revision_ids` as a :class:`.Revision`.
+
+        .. versionadded:: 0.9.4
+
+        """
+        return self.revision_map.get_revisions(self.up_revision_ids)
+
+    @property
+    def down_revisions(self):
+        """Get :attr:`~.MigrationInfo.down_revision_ids` as a tuple of
+        :class:`Revisions <.Revision>`."""
+        return self.revision_map.get_revisions(self.down_revision_ids)
+
+    @property
+    def source_revisions(self):
+        """Get :attr:`~MigrationInfo.source_revision_ids` as a tuple of
+        :class:`Revisions <.Revision>`."""
+        return self.revision_map.get_revisions(self.source_revision_ids)
+
+    @property
+    def destination_revisions(self):
+        """Get :attr:`~MigrationInfo.destination_revision_ids` as a tuple of
+        :class:`Revisions <.Revision>`."""
+        return self.revision_map.get_revisions(self.destination_revision_ids)
+
+
 class MigrationStep(object):
     @property
     def name(self):
@@ -538,7 +750,7 @@ class MigrationStep(object):
         return "%s %s -> %s" % (
             self.name,
             util.format_as_comma(self.from_revisions_no_deps),
-            util.format_as_comma(self.to_revisions_no_deps)
+            util.format_as_comma(self.to_revisions_no_deps),
         )
 
     def __str__(self):
@@ -547,7 +759,7 @@ class MigrationStep(object):
                 self.name,
                 util.format_as_comma(self.from_revisions_no_deps),
                 util.format_as_comma(self.to_revisions_no_deps),
-                self.doc
+                self.doc,
             )
         else:
             return self.short_log
@@ -565,13 +777,16 @@ class RevisionStep(MigrationStep):
 
     def __repr__(self):
         return "RevisionStep(%r, is_upgrade=%r)" % (
-            self.revision.revision, self.is_upgrade
+            self.revision.revision,
+            self.is_upgrade,
         )
 
     def __eq__(self, other):
-        return isinstance(other, RevisionStep) and \
-            other.revision == self.revision and \
-            self.is_upgrade == other.is_upgrade
+        return (
+            isinstance(other, RevisionStep)
+            and other.revision == self.revision
+            and self.is_upgrade == other.is_upgrade
+        )
 
     @property
     def doc(self):
@@ -582,26 +797,26 @@ class RevisionStep(MigrationStep):
         if self.is_upgrade:
             return self.revision._all_down_revisions
         else:
-            return (self.revision.revision, )
+            return (self.revision.revision,)
 
     @property
     def from_revisions_no_deps(self):
         if self.is_upgrade:
             return self.revision._versioned_down_revisions
         else:
-            return (self.revision.revision, )
+            return (self.revision.revision,)
 
     @property
     def to_revisions(self):
         if self.is_upgrade:
-            return (self.revision.revision, )
+            return (self.revision.revision,)
         else:
             return self.revision._all_down_revisions
 
     @property
     def to_revisions_no_deps(self):
         if self.is_upgrade:
-            return (self.revision.revision, )
+            return (self.revision.revision,)
         else:
             return self.revision._versioned_down_revisions
 
@@ -637,31 +852,31 @@ class RevisionStep(MigrationStep):
 
         if other_heads:
             ancestors = set(
-                r.revision for r in
-                self.revision_map._get_ancestor_nodes(
-                    self.revision_map.get_revisions(other_heads),
-                    check=False
+                r.revision
+                for r in self.revision_map._get_ancestor_nodes(
+                    self.revision_map.get_revisions(other_heads), check=False
                 )
             )
             from_revisions = list(
-                set(self.from_revisions).difference(ancestors))
+                set(self.from_revisions).difference(ancestors)
+            )
         else:
             from_revisions = list(self.from_revisions)
 
         return (
             # delete revs, update from rev, update to rev
-            list(from_revisions[0:-1]), from_revisions[-1],
-            self.to_revisions[0]
+            list(from_revisions[0:-1]),
+            from_revisions[-1],
+            self.to_revisions[0],
         )
 
     def _unmerge_to_revisions(self, heads):
         other_heads = set(heads).difference([self.revision.revision])
         if other_heads:
             ancestors = set(
-                r.revision for r in
-                self.revision_map._get_ancestor_nodes(
-                    self.revision_map.get_revisions(other_heads),
-                    check=False
+                r.revision
+                for r in self.revision_map._get_ancestor_nodes(
+                    self.revision_map.get_revisions(other_heads), check=False
                 )
             )
             return list(set(self.to_revisions).difference(ancestors))
@@ -673,8 +888,9 @@ class RevisionStep(MigrationStep):
 
         return (
             # update from rev, update to rev, insert revs
-            self.from_revisions[0], to_revisions[-1],
-            to_revisions[0:-1]
+            self.from_revisions[0],
+            to_revisions[-1],
+            to_revisions[0:-1],
         )
 
     def should_create_branch(self, heads):
@@ -702,8 +918,7 @@ class RevisionStep(MigrationStep):
 
         downrevs = self.revision._all_down_revisions
 
-        if len(downrevs) > 1 and \
-                len(heads.intersection(downrevs)) > 1:
+        if len(downrevs) > 1 and len(heads.intersection(downrevs)) > 1:
             return True
 
         return False
@@ -722,8 +937,9 @@ class RevisionStep(MigrationStep):
     def update_version_num(self, heads):
         if not self._has_scalar_down_revision:
             downrev = heads.intersection(self.revision._all_down_revisions)
-            assert len(downrev) == 1, \
-                "Can't do an UPDATE because downrevision is ambiguous"
+            assert (
+                len(downrev) == 1
+            ), "Can't do an UPDATE because downrevision is ambiguous"
             down_revision = list(downrev)[0]
         else:
             down_revision = self.revision._all_down_revisions[0]
@@ -741,14 +957,25 @@ class RevisionStep(MigrationStep):
     def insert_version_num(self):
         return self.revision.revision
 
+    @property
+    def info(self):
+        return MigrationInfo(
+            revision_map=self.revision_map,
+            up_revisions=self.revision.revision,
+            down_revisions=self.revision._all_down_revisions,
+            is_upgrade=self.is_upgrade,
+            is_stamp=False,
+        )
+
 
 class StampStep(MigrationStep):
-    def __init__(self, from_, to_, is_upgrade, branch_move):
+    def __init__(self, from_, to_, is_upgrade, branch_move, revision_map=None):
         self.from_ = util.to_tuple(from_, default=())
         self.to_ = util.to_tuple(to_, default=())
         self.is_upgrade = is_upgrade
         self.branch_move = branch_move
         self.migration_fn = self.stamp_revision
+        self.revision_map = revision_map
 
     doc = None
 
@@ -756,11 +983,13 @@ class StampStep(MigrationStep):
         return None
 
     def __eq__(self, other):
-        return isinstance(other, StampStep) and \
-            other.from_revisions == self.revisions and \
-            other.to_revisions == self.to_revisions and \
-            other.branch_move == self.branch_move and \
-            self.is_upgrade == other.is_upgrade
+        return (
+            isinstance(other, StampStep)
+            and other.from_revisions == self.revisions
+            and other.to_revisions == self.to_revisions
+            and other.branch_move == self.branch_move
+            and self.is_upgrade == other.is_upgrade
+        )
 
     @property
     def from_revisions(self):
@@ -796,15 +1025,17 @@ class StampStep(MigrationStep):
     def merge_branch_idents(self, heads):
         return (
             # delete revs, update from rev, update to rev
-            list(self.from_[0:-1]), self.from_[-1],
-            self.to_[0]
+            list(self.from_[0:-1]),
+            self.from_[-1],
+            self.to_[0],
         )
 
     def unmerge_branch_idents(self, heads):
         return (
             # update from rev, update to rev, insert revs
-            self.from_[0], self.to_[-1],
-            list(self.to_[0:-1])
+            self.from_[0],
+            self.to_[-1],
+            list(self.to_[0:-1]),
         )
 
     def should_delete_branch(self, heads):
@@ -818,3 +1049,18 @@ class StampStep(MigrationStep):
 
     def should_unmerge_branches(self, heads):
         return len(self.to_) > 1
+
+    @property
+    def info(self):
+        up, down = (
+            (self.to_, self.from_)
+            if self.is_upgrade
+            else (self.from_, self.to_)
+        )
+        return MigrationInfo(
+            revision_map=self.revision_map,
+            up_revisions=up,
+            down_revisions=down,
+            is_upgrade=self.is_upgrade,
+            is_stamp=True,
+        )
